<?php
/**
 * VW Security Guard Theme Customizer
 *
 * @package VW Security Guard
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_security_guard_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_security_guard_custom_controls' );

function vw_security_guard_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_security_guard_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-security-guard' ),
	    'description' => __( 'Description of what this panel does.', 'vw-security-guard' ),
	) );

	$wp_customize->add_section( 'vw_security_guard_left_right', array(
    	'title'      => __( 'General Settings', 'vw-security-guard' ),
		'priority'   => 30,
		'panel' => 'vw_security_guard_panel_id'
	) );

	$wp_customize->add_setting('vw_security_guard_width_option',array(
        'default' => __('Full Width','vw-security-guard'),
        'sanitize_callback' => 'vw_security_guard_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Security_Guard_Image_Radio_Control($wp_customize, 'vw_security_guard_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-security-guard'),
        'description' => __('Here you can change the width layout of Website.','vw-security-guard'),
        'section' => 'vw_security_guard_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_security_guard_theme_options',array(
        'default' => __('Right Sidebar','vw-security-guard'),
        'sanitize_callback' => 'vw_security_guard_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_security_guard_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-security-guard'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-security-guard'),
        'section' => 'vw_security_guard_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-security-guard'),
            'Right Sidebar' => __('Right Sidebar','vw-security-guard'),
            'One Column' => __('One Column','vw-security-guard'),
            'Three Columns' => __('Three Columns','vw-security-guard'),
            'Four Columns' => __('Four Columns','vw-security-guard'),
            'Grid Layout' => __('Grid Layout','vw-security-guard')
        ),
	));

	$wp_customize->add_setting('vw_security_guard_page_layout',array(
        'default' => __('One Column','vw-security-guard'),
        'sanitize_callback' => 'vw_security_guard_sanitize_choices'
	));
	$wp_customize->add_control('vw_security_guard_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-security-guard'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-security-guard'),
        'section' => 'vw_security_guard_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-security-guard'),
            'Right Sidebar' => __('Right Sidebar','vw-security-guard'),
            'One Column' => __('One Column','vw-security-guard')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_security_guard_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-security-guard' ),
		'priority'   => 30,
		'panel' => 'vw_security_guard_panel_id'
	) );

	$wp_customize->add_setting('vw_security_guard_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_location',array(
		'label'	=> __('Add location','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_security_guard_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_button_text',array(
		'label'	=> __('Add button text','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_security_guard_button_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_security_guard_button_link',array(
		'label'	=> __('Add button url','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('vw_security_guard_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_email_text',array(
		'label'	=> __('Add Text','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_security_guard_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_email_address',array(
		'label'	=> __('Add Email Address','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_security_guard_call_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_call_text',array(
		'label'	=> __('Add Text','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_security_guard_call_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_call_number',array(
		'label'	=> __('Add Contact Number','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_security_guard_time_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_time_text',array(
		'label'	=> __('Add Text','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_security_guard_timming',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_timming',array(
		'label'	=> __('Add Timming','vw-security-guard'),
		'section'=> 'vw_security_guard_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_security_guard_search_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_security_guard_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Security_Guard_Toggle_Switch_Custom_Control( $wp_customize, 'vw_security_guard_search_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Search','vw-security-guard' ),
          'section' => 'vw_security_guard_topbar'
    )));
    
	//Slider
	$wp_customize->add_section( 'vw_security_guard_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-security-guard' ),
		'priority'   => null,
		'panel' => 'vw_security_guard_panel_id'
	) );

	$wp_customize->add_setting( 'vw_security_guard_slider_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_security_guard_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Security_Guard_Toggle_Switch_Custom_Control( $wp_customize, 'vw_security_guard_slider_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Slider','vw-security-guard' ),
          'section' => 'vw_security_guard_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_security_guard_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_security_guard_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_security_guard_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-security-guard' ),
			'description' => __('Slider image size (1500 x 590)','vw-security-guard'),
			'section'  => 'vw_security_guard_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_security_guard_slider_content_option',array(
        'default' => __('Left','vw-security-guard'),
        'sanitize_callback' => 'vw_security_guard_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Security_Guard_Image_Radio_Control($wp_customize, 'vw_security_guard_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-security-guard'),
        'section' => 'vw_security_guard_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_security_guard_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_security_guard_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-security-guard' ),
		'section'     => 'vw_security_guard_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_security_guard_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_security_guard_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_security_guard_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_security_guard_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-security-guard' ),
	'section'     => 'vw_security_guard_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_security_guard_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-security-guard'),
      '0.1' =>  esc_attr('0.1','vw-security-guard'),
      '0.2' =>  esc_attr('0.2','vw-security-guard'),
      '0.3' =>  esc_attr('0.3','vw-security-guard'),
      '0.4' =>  esc_attr('0.4','vw-security-guard'),
      '0.5' =>  esc_attr('0.5','vw-security-guard'),
      '0.6' =>  esc_attr('0.6','vw-security-guard'),
      '0.7' =>  esc_attr('0.7','vw-security-guard'),
      '0.8' =>  esc_attr('0.8','vw-security-guard'),
      '0.9' =>  esc_attr('0.9','vw-security-guard')
	),
	));

	//Security Service
	$wp_customize->add_section( 'vw_security_guard_articles_section' , array(
    	'title'      => __( 'Security Services', 'vw-security-guard' ),
		'priority'   => null,
		'panel' => 'vw_security_guard_panel_id'
	) );
	
	$wp_customize->add_setting('vw_security_guard_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_section_title',array(
		'label'	=> __('Section Title','vw-security-guard'),
		'section'=> 'vw_security_guard_articles_section',
		'setting'=> 'vw_security_guard_section_title',
		'type'=> 'text'
	));	

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_security_guard_security_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_security_guard_sanitize_choices',
	));
	$wp_customize->add_control('vw_security_guard_security_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display services','vw-security-guard'),
		'description' => __('Image size (270 x 345)','vw-security-guard'),
		'section' => 'vw_security_guard_articles_section',
	));

	//Services excerpt
	$wp_customize->add_setting( 'vw_security_guard_services_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_security_guard_services_excerpt_number', array(
		'label'       => esc_html__( 'Services Excerpt length','vw-security-guard' ),
		'section'     => 'vw_security_guard_articles_section',
		'type'        => 'range',
		'settings'    => 'vw_security_guard_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_security_guard_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-security-guard'),
		'panel' => 'vw_security_guard_panel_id',
	));	

	$wp_customize->add_setting( 'vw_security_guard_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_security_guard_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Security_Guard_Toggle_Switch_Custom_Control( $wp_customize, 'vw_security_guard_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-security-guard' ),
        'section' => 'vw_security_guard_blog_post'
    )));

    $wp_customize->add_setting( 'vw_security_guard_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_security_guard_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Security_Guard_Toggle_Switch_Custom_Control( $wp_customize, 'vw_security_guard_toggle_author',array(
		'label' => esc_html__( 'Author','vw-security-guard' ),
		'section' => 'vw_security_guard_blog_post'
    )));

    $wp_customize->add_setting( 'vw_security_guard_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_security_guard_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Security_Guard_Toggle_Switch_Custom_Control( $wp_customize, 'vw_security_guard_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-security-guard' ),
		'section' => 'vw_security_guard_blog_post'
    )));

    $wp_customize->add_setting( 'vw_security_guard_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_security_guard_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-security-guard' ),
		'section'     => 'vw_security_guard_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_security_guard_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Creation
	$wp_customize->add_section( 'vw_security_guard_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-security-guard' ),
		'priority' => null,
		'panel' => 'vw_security_guard_panel_id'
	) );

	$wp_customize->add_setting('vw_security_guard_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Security_Guard_Content_Creation( $wp_customize, 'vw_security_guard_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-security-guard' ),
		),
		'section' => 'vw_security_guard_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-security-guard' ),
	) ) );
	
	//Footer Text
	$wp_customize->add_section('vw_security_guard_footer',array(
		'title'	=> __('Footer','vw-security-guard'),
		'description'=> __('This section will appear in the footer','vw-security-guard'),
		'panel' => 'vw_security_guard_panel_id',
	));	
	
	$wp_customize->add_setting('vw_security_guard_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_security_guard_footer_text',array(
		'label'	=> __('Copyright Text','vw-security-guard'),
		'section'=> 'vw_security_guard_footer',
		'setting'=> 'vw_security_guard_footer_text',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_security_guard_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_security_guard_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Security_Guard_Toggle_Switch_Custom_Control( $wp_customize, 'vw_security_guard_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-security-guard' ),
      	'section' => 'vw_security_guard_footer'
    )));

	$wp_customize->add_setting('vw_security_guard_scroll_top_alignment',array(
        'default' => __('Right','vw-security-guard'),
        'sanitize_callback' => 'vw_security_guard_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Security_Guard_Image_Radio_Control($wp_customize, 'vw_security_guard_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-security-guard'),
        'section' => 'vw_security_guard_footer',
        'settings' => 'vw_security_guard_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));	
}

add_action( 'customize_register', 'vw_security_guard_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Security_Guard_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Security_Guard_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Security_Guard_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Security Pro Theme', 'vw-security-guard' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-security-guard' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/security-guard-wordpress-theme/'),
		)));

		$manager->add_section(new VW_Security_Guard_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-security-guard' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-security-guard' ),
			'pro_url'  => admin_url('themes.php?page=vw_security_guard_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-security-guard-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-security-guard-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Security_Guard_Customize::get_instance();